@@ -11,25 +11,25 @@ from sdc_helpers.slack_helper import SlackHelper
 
 
 def retry_handler(
-        exceptions,
-        total_tries: int = 4,
-        initial_wait: float = 0.5,
-        backoff_factor: int = 2,
-        should_raise: bool = False
+    exceptions,
+    total_tries: int = 4,
+    initial_wait: float = 0.5,
+    backoff_factor: int = 2,
+    should_raise: bool = False,
 ):
     """
-        Decorator - managing API failures
+    Decorator - managing API failures
 
-        args:
-            exceptions (Exception): Exception instance or list of
-            Exception instances to catch & retry
-            total_tries (int): Total retry attempts
-            initial_wait (float): initial delay between retry attempts in seconds
-            backoff_factor (int): multiplier used to further randomize back off
-            should_raise (bool): Raise exception after all retires fail
+    args:
+        exceptions (Exception): Exception instance or list of
+        Exception instances to catch & retry
+        total_tries (int): Total retry attempts
+        initial_wait (float): initial delay between retry attempts in seconds
+        backoff_factor (int): multiplier used to further randomize back off
+        should_raise (bool): Raise exception after all retires fail
 
-        return:
-            wrapped function's response
+    return:
+        wrapped function's response
     """
 
     def retry_decorator(function):
@@ -39,7 +39,7 @@ def retry_handler(
             _tries, _delay = total_tries, initial_wait
             while _tries > 0:
                 try:
-                    print(f'Attempt {total_tries + 1 - _tries}')
+                    print(f"Attempt {total_tries + 1 - _tries}")
                     return function(*args, **kwargs)
                 except exceptions as exception:
                     # get logger message
@@ -47,18 +47,20 @@ def retry_handler(
                         slack_helper = SlackHelper()
                         slack_helper.send_critical(
                             message=str(
-                                f'Function: {function.__name__}\n'
-                                f'Failed despite best efforts after {total_tries} tries\n'
-                                f'Exception {exception}.'
+                                f"Function: {function.__name__}\n"
+                                f"Failed despite best efforts after {total_tries} tries\n"
+                                f"Exception {exception}."
                             )
                         )
 
                         if should_raise:
                             raise exception
                     else:
-                        msg = str(f'Function: {function.__name__}\n'
-                                  f'Exception {exception}.\n'
-                                  f'Retrying in {_delay} seconds!')
+                        msg = str(
+                            f"Function: {function.__name__}\n"
+                            f"Exception {exception}.\n"
+                            f"Retrying in {_delay} seconds!"
+                        )
                     # log with print
                     print(msg)
                     # decrement _tries
@@ -74,36 +76,34 @@ def retry_handler(
 
 
 def request_handler(
-        wait: float = 0,
-        backoff_factor: float = 0.01,
-        backoff_method: str = 'random'
+    wait: float = 0, backoff_factor: float = 0.01, backoff_method: str = "random"
 ):
     """
-        Decorator - managing API failures
+    Decorator - managing API failures
 
-        Args:
-            wait (float, optional): [description].
-                Defaults to 100 seconds for GoogleAnalytics.
-                Initial delay between retry attempts in seconds
-            backoff_factor (float, optional):
-                [description]. Defaults to 0.1.
-                Multiplier used to further randomize delay
-            backoff_method (str, optional):
-                [description]. Defaults to 'random'. hHow to apply backoff
-        return:
-            wrapped function's response
+    Args:
+        wait (float, optional): [description].
+            Defaults to 100 seconds for GoogleAnalytics.
+            Initial delay between retry attempts in seconds
+        backoff_factor (float, optional):
+            [description]. Defaults to 0.1.
+            Multiplier used to further randomize delay
+        backoff_method (str, optional):
+            [description]. Defaults to 'random'. hHow to apply backoff
+    return:
+        wrapped function's response
     """
 
     def retry_decorator(function):
         @wraps(function)
         def func_with_retries(*args, **kwargs):
             """wrapper function to decorate function with retry functionality"""
-            if backoff_method == 'random':
+            if backoff_method == "random":
                 _delay = wait * (1 + backoff_factor * random())
             else:
                 _delay = wait
 
-            print(f'Waiting {_delay} seconds before attempt')
+            print(f"Waiting {_delay} seconds before attempt")
             time.sleep(_delay)
             return function(*args, **kwargs)
 
