@@ -22,7 +22,7 @@ def tracking_metadata(data_object: list, **kwargs) -> list:
         "id_value",
         "config_datetime",
         "configuration",
-        "byte_size"
+        "byte_size",
     ]
 
     dataset = {}
@@ -30,7 +30,9 @@ def tracking_metadata(data_object: list, **kwargs) -> list:
         try:
             dataset[key] = kwargs.get(key)
         except KeyError:
-            raise KeyError("The tracking_metadata only supports specific key value pairs.")
+            raise KeyError(
+                "The tracking_metadata only supports specific key value pairs."
+            )
 
     data_object.append(dataset)
     return data_object
