@@ -61,8 +61,8 @@ class GAV3Reader:
 
         return data_set
 
-    @request_handler(wait=0.5, backoff_factor=0.1)
-    @retry_handler(exceptions=(socket.timeout, HttpError), total_tries=5, initial_wait=60, backoff_factor=2)
+    @request_handler(wait=1, backoff_factor=.5)
+    @retry_handler(exceptions=(socket.timeout, HttpError), total_tries=5, initial_wait=60, backoff_factor=5)
     def _query_handler(self, view_id, service, start_index):
         """
         Separated query method to handle retry and delay methods.
@@ -80,7 +80,7 @@ class GAV3Reader:
                 dimensions=",".join(self.config.get("dimensions", [])),
                 sort=self.config.get("sort", None),
                 filters=self.config.get("filters", None),
-                max_results=self.config.get("max_results", 5000),
+                max_results=self.config.get("max_results", 10000),
                 start_index=start_index,
                 samplingLevel="HIGHER_PRECISION",
                 include_empty_rows=True,
@@ -128,7 +128,6 @@ class GAV3Reader:
               Analytics view (profile) ID for which the query will retrieve the data.
         """
         for view_id in self.config.get("view_ids"):
-            data_set = []
             service = self._get_service()  # new service for each view_id
             page_token = 1  # handle paging of response
             while True:
@@ -139,9 +138,7 @@ class GAV3Reader:
                     print("No more data in response.")
                     break
                 page_token += response.get("itemsPerPage", 0)
-                data_set.append(self._normalize_data(response))
-
-            yield data_set
+                yield  self._normalize_data(response)
 
 
 class BaseGAV4Reader:
