@@ -223,7 +223,8 @@ class CustomOneSignalReader:
                     # append all responses to the dataset
                     data_set = pool.map(self._view_notifications_get, json_payloads)
                     for data in data_set:
-                        self.data_set.append(data)
+                        for row in data:
+                            self.data_set.append(row)
             else:
                 # Run a stock-standard request process.
                 for payload in json_payloads:
